==> xmule-1.10.0a.tar.bz2: xmule-1.10.0a/src/CommentDialogLst.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef COMMENTDLGLIST_H
#define COMMENTDLGLIST_H

#include <wx/dialog.h>
#include <wx/listctrl.h>

#include "resource.h"
#include "wintypes.h"

class CPartFile;

// CCommentDialogLst dialog 

class CCommentDialogLst : public wxDialog
{ 
  //DECLARE_DYNAMIC(CCommentDialogLst) 

public: 
   CCommentDialogLst(wxWindow* pParent,CPartFile* file); 
   virtual ~CCommentDialogLst(); 
   void Localize(); 
   virtual bool OnInitDialog(); 
   //CHyperTextCtrl lstbox; 
   wxListCtrl *pmyListCtrl;

// Dialog Data 
   enum { IDD = IDD_COMMENTLST }; 
protected: 
   //virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support 
   //DECLARE_MESSAGE_MAP() 
   DECLARE_EVENT_TABLE()
public: 
   void OnBnClickedApply(wxCommandEvent& evt); 
   void OnBnClickedRefresh(wxCommandEvent& evt); 
private: 
   void CompleteList(); 
   CPartFile* m_file; 
};

#endif

==> xmule-1.12.2.tar.bz2: xmule-1.12.2/src/CommentDialogLst.h <==
// The xMule Project - A Peer-2-Peer File Sharing Program
//
// Copyright (C) 2003-2005 Theodore R. Smith ( hopeseekr@gmail.com / http://www.xmule.ws/ )
// Copyright (C) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of Version 2 of the GNU General Public
// License as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

#ifndef COMMENTDLGLIST_H
#define COMMENTDLGLIST_H

#include <wx/dialog.h>
#include <wx/listctrl.h>

#include "resource.h"                       // audited
#include "wintypes.h"

class CPartFile;

// CCommentDialogLst dialog 

class CCommentDialogLst : public wxDialog
{ 
  //DECLARE_DYNAMIC(CCommentDialogLst) 

public: 
   CCommentDialogLst(wxWindow* pParent,CPartFile* file); 
   virtual ~CCommentDialogLst(); 
   void Localize(); 
   virtual bool OnInitDialog(); 
   //CHyperTextCtrl lstbox; 
   wxListCtrl *pmyListCtrl;

// Dialog Data 
   enum { IDD = IDD_COMMENTLST }; 
protected: 
   //virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support 
   //DECLARE_MESSAGE_MAP() 
   DECLARE_EVENT_TABLE()
public: 
   void OnBnClickedApply(wxCommandEvent& evt); 
   void OnBnClickedRefresh(wxCommandEvent& evt); 
private: 
   void CompleteList(); 
   CPartFile* m_file; 
};

#endif
